SecureStorageException class

Thrown when secure storage operations fail.

Inheritance

Constructors

SecureStorageException({String? key, required String message, String? code = 'SECURE_STORAGE_ERROR', Object? originalError})
const

Properties

code String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key String?
final
message String
finalinherited
originalError Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited