SecurityException class

Base exception for all SecureBankKit security errors.

Implemented types
Implementers

Constructors

SecurityException({required String message, String? code, Object? originalError})
const

Properties

code String?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
originalError Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited