SecurityLogger class

A simple static logger for SecureBankKit.

Logging is disabled by default. Call SecurityLogger.enable to start receiving debug output.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isEnabled bool
Whether logging is currently enabled.
no setter

Static Methods

disable() → void
Disable logging output.
enable() → void
Enable logging output.
error(String message, {Object? error, StackTrace? stackTrace}) → void
Log an error with an optional error object and stackTrace.
info(String message) → void
Log an informational message.
warning(String message) → void
Log a warning.