SecurityStatus class
Immutable snapshot of all security checks.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAppIntegrityValid → bool
-
final
- isCertificatePinningValid → bool
-
final
- isEmulator → bool
-
final
- isRooted → bool
-
final
- isRuntimeHooked → bool
-
final
- isScreenBeingRecorded → bool
-
final
- isSecure → bool
-
truewhen all enabled security checks pass.no setter - isTampered → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override