RootDetectionRepository class abstract

Contract for root / jailbreak detection.

Implementers

Constructors

RootDetectionRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isDeviceRooted() Future<SecurityResult<bool>>
Returns true if the device is rooted or jailbroken.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited