RuntimeProtectionRepository class abstract

Contract for runtime instrumentation / hooking detection.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isRuntimeHooked() Future<SecurityResult<bool>>
Returns true when a hooking framework (Frida, Xposed, etc.) or an attached debugger is detected at runtime.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited