SecureStorage class

Sub-accessor for secure storage operations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete({required String key}) Future<SecurityResult<void>>
deleteAll() Future<SecurityResult<void>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read({required String key}) Future<SecurityResult<String?>>
toString() String
A string representation of this object.
inherited
write({required String key, required String value}) Future<SecurityResult<void>>

Operators

operator ==(Object other) bool
The equality operator.
inherited