CertificatePinningDatasource class
Pure-Dart datasource for TLS certificate pinning validation.
Connects to host:443, retrieves the server certificate,
and compares its SHA-256 fingerprint against the provided pins.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateCertificate(
{required String host, required List< String> pins}) → Future<bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited