SecurityStatus class

Immutable snapshot of all security checks.

Constructors

SecurityStatus({required bool isRooted, required bool isAppIntegrityValid, required bool isCertificatePinningValid})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isAppIntegrityValid bool
final
isCertificatePinningValid bool
final
isRooted bool
final
isSecure bool
true when the device is not rooted, app integrity is valid, and certificate pinning has passed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override