CheckTamperUseCase class
Checks whether the app bundle / APK has been tampered with.
Constructors
- CheckTamperUseCase(TamperDetectionRepository _repository)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
) → Future< SecurityResult< bool> > -
getSignatureHash(
) → Future< SecurityResult< String?> > - Returns the SHA-256 hex fingerprint of the app's signing certificate. Useful for one-time setup to discover and pin the expected hash.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited