MethodChannelSecurity class
Single method channel bridge to native Android/iOS code.
All calls use the feature#action naming convention, e.g.
root#isDeviceRooted, screenshot#enable.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableScreenshotProtection(
) → Future< void> -
enableScreenshotProtection(
) → Future< void> -
isAppIntegrityValid(
) → Future< bool> -
isDeviceRooted(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
secureStorageDelete(
{required String key}) → Future< void> -
secureStorageDeleteAll(
) → Future< void> -
secureStorageRead(
{required String key}) → Future< String?> -
secureStorageWrite(
{required String key, required String value}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- channel → MethodChannel
-
Visible for testing – allows injection of a mock channel.
no setter